.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`restoration`
==========================
.. automodule:: skimage.restoration

.. currentmodule:: skimage.restoration
.. autosummary::

   skimage.restoration.calibrate_denoiser
   skimage.restoration.cycle_spin
   skimage.restoration.denoise_bilateral
   skimage.restoration.denoise_nl_means
   skimage.restoration.denoise_tv_bregman
   skimage.restoration.denoise_tv_chambolle
   skimage.restoration.denoise_wavelet
   skimage.restoration.estimate_sigma
   skimage.restoration.inpaint_biharmonic
   skimage.restoration.richardson_lucy
   skimage.restoration.unsupervised_wiener
   skimage.restoration.unwrap_phase
   skimage.restoration.wiener



calibrate_denoiser
------------------

.. autofunction:: skimage.restoration.calibrate_denoiser


.. include:: skimage.restoration.calibrate_denoiser.examples

cycle_spin
----------

.. autofunction:: skimage.restoration.cycle_spin


.. include:: skimage.restoration.cycle_spin.examples

denoise_bilateral
-----------------

.. autofunction:: skimage.restoration.denoise_bilateral


.. include:: skimage.restoration.denoise_bilateral.examples

denoise_nl_means
----------------

.. autofunction:: skimage.restoration.denoise_nl_means


.. include:: skimage.restoration.denoise_nl_means.examples

denoise_tv_bregman
------------------

.. autofunction:: skimage.restoration.denoise_tv_bregman


.. include:: skimage.restoration.denoise_tv_bregman.examples

denoise_tv_chambolle
--------------------

.. autofunction:: skimage.restoration.denoise_tv_chambolle


.. include:: skimage.restoration.denoise_tv_chambolle.examples

denoise_wavelet
---------------

.. autofunction:: skimage.restoration.denoise_wavelet


.. include:: skimage.restoration.denoise_wavelet.examples

estimate_sigma
--------------

.. autofunction:: skimage.restoration.estimate_sigma


.. include:: skimage.restoration.estimate_sigma.examples

inpaint_biharmonic
------------------

.. autofunction:: skimage.restoration.inpaint_biharmonic


.. include:: skimage.restoration.inpaint_biharmonic.examples

richardson_lucy
---------------

.. autofunction:: skimage.restoration.richardson_lucy


.. include:: skimage.restoration.richardson_lucy.examples

unsupervised_wiener
-------------------

.. autofunction:: skimage.restoration.unsupervised_wiener


.. include:: skimage.restoration.unsupervised_wiener.examples

unwrap_phase
------------

.. autofunction:: skimage.restoration.unwrap_phase


.. include:: skimage.restoration.unwrap_phase.examples

wiener
------

.. autofunction:: skimage.restoration.wiener


.. include:: skimage.restoration.wiener.examples

